@@ -125,7 +125,9 @@ class Estimator(AbstractEstimator):
         if self.__last_design_point != design_point:
             X, y = self.__prepare_data(design_point)
         if not self.__last_design_point:
-            self.__reg = skm.trees.iSOUPTreeRegressor()
+            self.__reg = skm.trees.iSOUPTreeRegressor(
+                leaf_prediction="adaptive", learning_ratio_const=False,
+            )
             self.__reg.fit(X, y)
             self.__last_design_point = design_point
             self.__last_len = len(X)
